![](./KlayLogo.png)
# KLay - KLIFF Layers, trainable and pre-trained layers for MLIPs

KLIFF compatible ML layers you can mould to your needs. Usable for general neural network architectures as well. Works out of the box with KLIFF.


